==> openjdk-11_11.0.29+7.orig.tar.xz: openjdk-11-11.0.29+7/test/jdk/javax/security/auth/callback/PasswordCallback/CheckCleanerBound.java <==
/*
 * Copyright (C) 2022 THL A29 Limited, a Tencent company. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 8284910
 * @summary Check that the cleaner is not bound to the PasswordCallback object
 */

import javax.security.auth.callback.PasswordCallback;
import java.util.WeakHashMap;

public final class CheckCleanerBound {
    private final static WeakHashMap<PasswordCallback, ?> weakHashMap =
            new WeakHashMap<>();

    public static void main(String[] args) throws Exception {
        // Create an object
        PasswordCallback passwordCallback =
                new PasswordCallback("Password: ", false);
        passwordCallback.setPassword("ThisIsAPassword".toCharArray());

        weakHashMap.put(passwordCallback, null);
        passwordCallback = null;

        // Check if the PasswordCallback object could be collected.
        // Wait to trigger the cleanup.
        for (int i = 0; i < 10 && weakHashMap.size() != 0; i++) {
            System.gc();
            Thread.sleep(100);
        }

        // Check if the object has been collected.  The collection will not
        // happen if the cleaner implementation in PasswordCallback is bound
        // to the PasswordCallback object.
        if (weakHashMap.size() > 0) {
            throw new RuntimeException(
                "PasswordCallback object is not released");
        }
    }
}

==> openjdk-21_21.0.9+10.orig.tar.xz: openjdk-21-21.0.9+10/test/jdk/javax/security/auth/callback/PasswordCallback/CheckCleanerBound.java <==
/*
 * Copyright (C) 2022 THL A29 Limited, a Tencent company. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 8284910
 * @summary Check that the cleaner is not bound to the PasswordCallback object
 * @library /test/lib/
 * @build jdk.test.lib.util.ForceGC
 * @run main/othervm CheckCleanerBound
 */

import javax.security.auth.callback.PasswordCallback;
import java.lang.ref.WeakReference;
import jdk.test.lib.util.ForceGC;

public final class CheckCleanerBound {

    public static void main(String[] args) throws Exception {
        // Create an object
        PasswordCallback passwordCallback =
                new PasswordCallback("Password: ", false);
        passwordCallback.setPassword("ThisIsAPassword".toCharArray());

        WeakReference<PasswordCallback> weakRef =
                new WeakReference<>(passwordCallback);
        passwordCallback = null;

        // Check if the object has been collected.  The collection will not
        // happen if the cleaner implementation in PasswordCallback is bound
        // to the PasswordCallback object.
        if (!ForceGC.wait(() -> weakRef.refersTo(null))) {
            throw new RuntimeException(
                "PasswordCallback object is not released");
        }
    }
}
